@@ -61,12 +61,13 @@ class Advisor(object, metaclass=abc.ABCMeta):
         self.acq_optimizer_type = acq_optimizer_type
         self.init_num = initial_trials
         self.config_space = config_space
-        self.config_space.seed(self.rng.randint(MAXINT))
+        self.config_space_seed = self.rng.randint(MAXINT)
+        self.config_space.seed(self.config_space_seed)
         self.ref_point = ref_point
 
         # init history container
         if self.num_objs == 1:
-            self.history_container = HistoryContainer(task_id, self.num_constraints)
+            self.history_container = HistoryContainer(task_id, self.num_constraints, config_space=self.config_space)
         else:  # multi-objectives
             self.history_container = MOHistoryContainer(task_id, self.num_objs, self.num_constraints, ref_point)
 
@@ -103,13 +104,13 @@ class Advisor(object, metaclass=abc.ABCMeta):
                     self.acq_type = 'ei'
                 assert self.acq_type in ['ei', 'eips', 'logei', 'pi', 'lcb', 'lpei', ]
                 if self.surrogate_type is None:
-                    self.surrogate_type = 'prf'
+                    self.surrogate_type = 'gp'
             else:  # with constraints
                 if self.acq_type is None:
                     self.acq_type = 'eic'
                 assert self.acq_type in ['eic', ]
                 if self.surrogate_type is None:
-                    self.surrogate_type = 'prf'
+                    self.surrogate_type = 'gp'
                 if self.constraint_surrogate_type is None:
                     self.constraint_surrogate_type = 'gp'
 
